import logging
from .register import register
from .token import get_token
from .render import render, query, download

logging.basicConfig(level=logging.INFO,
                format='%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s',
                datefmt='%a, %d %b %Y %H:%M:%S')

class Aureport:
    def __init__(self, token=None):
        self._token = token
        self._host = 'https://autoreport.memect.cn'

    @property
    def token(self):
        return self._token

    @token.setter
    def token(self, token):
        self._token = token

    @property
    def host(self):
        return self._host

    @host.setter
    def host(self, host):
        self._host = host

    def request_report(self, data, fmt):
        if self._token is None:
            raise Exception("必须提供token.")
        report_id = render(self._host, data, self._token, fmt)
        url = query(self._host, report_id)
        download(url)

    def register(self, phone, passcode, name, title):
        token = register(self._host, phone=phone, passcode=passcode, name=name, title=title)
        self._token = token
        return token

    def get_token(self, phone, passcode):
        token = get_token(self._host, phone=phone, passcode=passcode)
        self._token = token
        return token
