import os
import json
import time
import logging
import requests
from urllib.parse import unquote

def render(host, data, token, fmt):
    if not fmt in ['ppt', 'doc']:
        raise Exception("报告类型目前支持ppt和doc")
    url = "{}/api/render/{}".format(host, fmt)
    data_post = {
        "data": data,
        "token": token
    }
    r = requests.post(url, data=json.dumps(data_post))
    res = json.loads(r.text)
    if r.status_code == 200:
        return res['report_id']
    else:
        raise Exception(res.get('error'))


def query(host, report_id):
    url = "{}/api/query_status/{}".format(host, report_id)
    res = {}
    s_time = time.time()
    while res.get('status', '') != 'done':
        if time.time() - s_time >= 10:
            logging.info("报告生成超时.")
            raise Exception("报告生成超时.")
        if res.get('error'):
            raise Exception(res.get('error'))
        time.sleep(1)
        logging.info("报告正在生成，请稍候...")
        r = requests.get(url)
        res = json.loads(r.text)
    return res.get('url', '')

def download(url):
    filename = os.path.basename(url)
    filename = unquote(filename)
    r = requests.get(url, stream=True)
    logging.info("正在下载报告：{}".format(filename))
    with open(filename, "wb") as f:
        for chunk in r.iter_content(chunk_size=512):
            if chunk:
                f.write(chunk)
